import SwiftUI
import HealthKit
import HKDatabase
import CoreLocation

struct ActivityDetailView: View {

    let activity: HKWorkoutActivity

    @State var locations: [CLLocation] = []

    @State var sampleCount: Int = 0

    private var metadata: [(key: String, value: Any)] {
        activity.metadata?.sorted { $0.key } ?? []
    }

    var body: some View {
        List {
            Section("Properties") {
                DetailRow("UUID", value: activity.uuid)
                DetailRow("Activity", value: activity.workoutConfiguration.activityType)
                DetailRow("Location", value: activity.workoutConfiguration.locationType)
                DetailRow("Swimming Location", value: activity.workoutConfiguration.swimmingLocationType)
                DetailRow("Lap Length", value: activity.workoutConfiguration.lapLength)
                DetailRow("Start", date: activity.startDate)
                DetailRow("End", date: activity.endDate)
                DetailRow("Duration", duration: activity.duration)
            }
            Section("Data") {
                if !locations.isEmpty {
                    NavigationLink(value: locations) {
                        DetailRow("Locations", value: "\(locations.count)")
                    }
                } else {
                    DetailRow("Locations", value: "0")
                }
                if sampleCount != 0 {
                    NavigationLink {
                        ActivitySamplesView(activity: activity)
                    } label: {
                        DetailRow("Samples", value: "\(sampleCount)")
                    }
                } else {
                    DetailRow("Samples", value: "0")
                }
            }
            if !(activity.metadata?.isEmpty ?? true) {
                Section("Metadata") {
                    ForEach(metadata, id: \.key) { (key, value) in
                        DetailRow(key, value: "\(value)")
                    }
                }
            }
        }
        .navigationTitle("Activity")
        .navigationDestination(for: [CLLocation].self) { locations in
            LocationSampleListView(samples: locations)
        }
        .onAppear(perform: load)
    }

    private func load() {
        Task {
            do {
                let samples = try HealthDatabase.shared.locationSamples(for: activity)
                    .sorted { $0.timestamp }
                //let sampleCount = try HealthDatabase.shared.sampleCount(for: activity)
                DispatchQueue.main.async {
                    self.locations = samples
                    //self.sampleCount = sampleCount
                }
            } catch {
                print("Failed to load location samples for activity: \(error)")
            }
        }
    }
}

#Preview {
    HealthDatabase.shared = .mock()
    return NavigationStack {
        ActivityDetailView(activity: .mock1)
    }
}
