import SwiftUI
import HealthKit
import HKDatabase
import SFSafeSymbols

struct ContentView: View {
    
    @State var navigationPath: NavigationPath = .init()

    @State var workouts: [Workout] = []

    var body: some View {
        NavigationStack(path: $navigationPath) {
            VStack {
                List {
                    ForEach(workouts) { workout in
                        NavigationLink(value: workout) {
                            VStack(alignment: .leading) {
                                Text(workout.typeString)
                                Text(workout.dateString)
                                    .font(.caption)
                                    .foregroundStyle(.secondary)
                            }
                        }
                    }
                }
            }
            .navigationTitle("Workouts")
            .navigationDestination(for: Workout.self) {
                WorkoutDetailView(workout: $0)
            }
            .toolbar {
                ToolbarItem {
                    NavigationLink {
                        SearchHealthStoreView()
                    } label: {
                        Image(systemSymbol: .magnifyingglass)
                    }
                }
            }
            .onAppear(perform: getPermissions)
        }
    }

    private func getPermissions() {
        Task {
            let store = HKHealthStore()
            do {
                let success = try await requestAllPermissions(in: store)
                print("Has permissions: \(success)")
            } catch {
                print("Error getting permissions: \(error)")
                return
            }
            do {
                let workouts = try HealthDatabase.shared.readAllWorkouts()
                DispatchQueue.main.async {
                    self.workouts = workouts.reversed()
                }
            } catch {
                print("Error getting workouts: \(error)")
                return
            }
        }
    }
}

#Preview {
    HealthDatabase.shared = .mock()
    return ContentView()
}

/*
 data_series.hfd_key -> location_series_data.series_identifier

 samples.data_id = data_series.data_id
 samples.data_id = quantity_samples.data_id
 samples.data_id = objects.data_id
 samples.data_id = quantity_sample_series.data_id

 objects.provenance = data_provenances.ROWID

 data_provenances.tz_name
 data_provenances.origin_device

 Samples -> Quantity Sample Series -> Quantity Series Data
 Samples -> Data Series


 quantity_sample_series.hfd_key = quantity_series_data.series_identifier

 */
